version 8.2
clear
set more off
set matsize 700
set mem 100m

log using durablesjm, replace

* This file attempts to calculate a consumption flow from durable items

* We are merging two of the three durable files.  The merged file contains the same information that was included in the 2002 data.
* We excluded the third file since it contained information that was inconsistent with the other two data files.  
* The excluded information for the 2005 data was also not included in the 2002 data.

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005\dwellingC1_cl.dta", clear
rename m13c1_q1b itemcode
sort hhid itemcode
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\dwellingC1_cl.dta", replace

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005\dwellingC2_cl.dta", clear
rename m13c2_q2b itemcode
sort hhid itemcode
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\dwellingC2_cl.dta", replace

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\dwellingC1_cl.dta", clear
sort hhid itemcode
merge hhid itemcode using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\dwellingC2_cl.dta"
tab _merge
drop _merge
sort hhid itemcode
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\durables_cljm.dta", replace

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\durables_cljm.dta", clear
des
compress

* Corrections to households incorrectly coded
replace hhid=509 if hhid==505
replace hhid=1502 if hhid==1505
replace hhid=2310 if hhid==2309
replace hhid=6902 if hhid==6901
replace hhid=8708 if hhid==8709
replace hhid=9308 if hhid==9309
replace hhid=16109 if hhid==16110
replace hhid=18210 if hhid==18211
replace hhid=23007 if hhid==23001
replace hhid=26009 if hhid==26010
replace hhid=26509 if hhid==26510
replace hhid=34210 if hhid==34206
replace hhid=34409 if hhid==34402
replace hhid=37507 if hhid==37506
replace hhid=41609 if hhid==41608
replace hhid=43211 if hhid==43201
replace hhid=44506 if hhid==44505
replace hhid=46411 if hhid==46410


* We droped item description for both files (in Albanian), and line number since it represents the same information contained in the variable itemcode.
drop m13c1_q1a m13c2_q00 m13c2_q2a

* codebook
rename m0_q00 psu
rename m13c1_q1c numitems
rename m13c2_q03 years
rename m13c2_q04 purch
rename  m13c2_q05 amount

* We are including items listed as payments for services under the same category as items purchased.
* There were only 20 items listed as payments for services.

*table itemcode years
*table itemcode amount

* We exclude 2 items that are likely to be used mainly for productive reasons: trucks and dumdum tractors.

drop if itemcode==123
drop if itemcode==124

* We make some corrections. In a few years, the years of acquisition are high-- after checking the
* the questionnaires, it was found that these are sewing machines, bicycles and wood stoves that
* household keep in the family for years... so they were left as they are. One needed correction

replace year=30 if hhid==29711 & years==90 & itemcode==112
sort hhid 

* Since there are households who refused to state/didn't know the current value of certain durable goods, 
* we replace these values with the mode of current value of each item's year of acquisition.

bysort years: egen mode= mode(amount) if itemcode==101, min missing
replace amount=mode if itemcode==101 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==102, min missing
replace amount=mode if itemcode==102 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==103, min missing
replace amount=mode if itemcode==103 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==104, min missing
replace amount=mode if itemcode==104 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==105, min missing
replace amount=mode if itemcode==105 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==106, min missing
replace amount=mode if itemcode==106 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==107, min missing
replace amount=mode if itemcode==107 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==108, min missing
replace amount=mode if itemcode==108 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==109, min missing
replace amount=mode if itemcode==109 & amount>3.50e+07
drop mode

bysort years: egen mode= mode(amount) if itemcode==110, min missing
replace amount=mode if itemcode==110 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==111, min missing
replace amount=mode if itemcode==111 & amount>3.50e+07
drop mode

* We spotted a 15 years old wood stove with a recorded amount of 0, which we replaced for the mode amount.
bysort years: egen mode=mode(amount) if itemcode==112, min missing
replace amount=mode if itemcode==112 & (amount>3.50e+07|amount==0)
drop mode

bysort years: egen mode=mode(amount) if itemcode==113, min missing
replace amount=mode if itemcode==113 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==114, min missing
replace amount=mode if itemcode==114 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==115, min missing
replace amount=mode if itemcode==115 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==116, min missing
replace amount=mode if itemcode==116 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==117, min missing
replace amount=mode if itemcode==117 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==118, min missing
replace amount=mode if itemcode==118 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==119, min missing
replace amount=mode if itemcode==119 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==120, min missing
replace amount=mode if itemcode==120 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==121, min missing
replace amount=mode if itemcode==121 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==122, min missing
replace amount=mode if itemcode==122 & amount>3.50e+07
drop mode

bysort years: egen mode=mode(amount) if itemcode==125, min missing
replace amount=mode if itemcode==125 & amount>3.50e+07
drop mode

drop if itemcode==.

tab itemcode
table itemcode, c(med years m years max years n years)


* We re-check for the strange values in "years."

sum years, det

tab years if itemcode==101
table years if itemcode==101, c(median amount n amount)

tab years if itemcode==102
table years if itemcode==102, c(median amount n amount)

tab years if itemcode==103
table years if itemcode==103, c(median amount n amount)

tab years if itemcode==104
table years if itemcode==104, c(median amount n amount)

tab years if itemcode==105
table years if itemcode==105, c(median amount n amount)

tab years if itemcode==106
table years if itemcode==106, c(median amount n amount)

tab years if itemcode==107
table years if itemcode==107, c(median amount n amount)

tab years if itemcode==108
table years if itemcode==108, c(median amount n amount)

tab years if itemcode==109
table years if itemcode==109, c(median amount n amount)

tab years if itemcode==110
table years if itemcode==110, c(median amount n amount)

tab years if itemcode==111
table years if itemcode==111, c(median amount n amount)

tab years if itemcode==112
table years if itemcode==112, c(median amount n amount)

tab years if itemcode==113
table years if itemcode==113, c(median amount n amount)

tab years if itemcode==114
table years if itemcode==114, c(median amount n amount)

tab years if itemcode==115
table years if itemcode==115, c(median amount n amount)

tab years if itemcode==116
table years if itemcode==116, c(median amount n amount)

tab years if itemcode==117
table years if itemcode==117, c(median amount n amount)

tab years if itemcode==118
table years if itemcode==118, c(median amount n amount)

tab years if itemcode==119
table years if itemcode==119, c(median amount n amount)

tab years if itemcode==120
table years if itemcode==120, c(median amount n amount)

tab years if itemcode==121
table years if itemcode==121, c(median amount n amount)

tab years if itemcode==122
table years if itemcode==122, c(median amount n amount)

tab years if itemcode==125
table years if itemcode==125, c(median amount n amount)

* We calculate mean age and maximum age

egen meanage=mean(years), by(itemcode)
gen maxage1=2*meanage
gen maxage2=3*meanage
count if years>maxage1
count if years>maxage2

table itemcode if years>maxage1, c(m amount max amount n amount) row
table itemcode if years>maxage2, c(m amount max amount n amount) row
gen remlife1=maxage1-years
replace remlife1=0 if remlife1<0
replace remlife1=2 if remlife1>0 & remlife1<2

gen remlife2=maxage2-years
replace remlife2=0 if remlife2<0
replace remlife2=2 if remlife2>0 & remlife2<2

gen value1=amount/remlife1
gen value2=amount/remlife2

table itemcode maxage1, c(mean remlife1)

table itemcode maxage2, c(mean remlife2)


* We check the relationship between age and value of the item (it should be negative)

count if amount==.
count if years==.
count if years==. & amount==.
drop if years==. & amount==.

count if amount==. & years!=.

* these values need to be estimated

tab itemcode if amount==. & years!=.

xi: reg amount years i.itemcode 

* The expected relationship holds.

* Check item by item: Smoothing out the relationship between value and age of the item, calculating the depreciation rate.

* ksm amount years if itemcode==101, lowess
* ksm amount years if itemcode==101 & amount<750000, lowess
qreg amount years if itemcode==101 & years<14
predict xb, xb
* graph amount xb years if itemcode==101 & amount<750000, c(.l)
tab xb if amount==. & itemcode==101 & years<14
replace amount=xb if amount==. & itemcode==101 & years<14
drop xb
gen deprate=-_b[years]/_b[_cons] if itemcode==101 & years<14
qreg amount years if itemcode==101 & years>=14
predict xb, xb
* graph amount xb years if itemcode==101 & amount<750000, c(.l)
tab xb if amount==. & itemcode==101 & years>=14
replace amount=xb if amount==. & itemcode==101 & years>=14
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==101 & years>=14

* ksm amount years if itemcode==102, lowess
qreg amount years if itemcode==102
predict xb, xb
* graph amount xb years if itemcode==102 & amount<450000, c(.l)
tab xb if amount==. & itemcode==102
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==102

* ksm amount years if itemcode==103 & amount<600000, lowess
qreg amount years if itemcode==103
predict xb, xb
* graph amount xb years if itemcode==103, c(.l)
tab xb if amount==. & itemcode==103
replace amount=xb if amount==. & itemcode==103
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==103

* ksm amount years if itemcode==104, lowess
qreg amount years if itemcode==104 & years<10
predict xb, xb
* graph amount xb years if itemcode==104, c(.l)
tab xb if amount==. & itemcode==104 & years<10
replace amount=xb if amount==. & itemcode==104 & years<10
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==104 & years<10
qreg amount years if itemcode==104 & years>=10
predict xb, xb
* graph amount xb years if itemcode==104, c(.l)
tab xb if amount==. & itemcode==104 & years>=10
replace amount=xb if amount==. & itemcode==104 & years>=10
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==104 & years>=10

* ksm amount years if itemcode==105, lowess
qreg amount years if itemcode==105
predict xb, xb
* graph amount xb years if itemcode==105, c(.l)
tab xb if amount==. & itemcode==105
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==105

* ksm amount years if itemcode==106, lowess
* ksm amount years if itemcode==106 & amount<1000000, lowess
qreg amount years if itemcode==106 & years<=10 
predict xb, xb
* graph amount xb years if itemcode==106 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==106 & years<=10
replace amount=xb if amount==. & itemcode==106 & years<=10
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==106 & years<=10
qreg amount years if itemcode==106 & years>10 
predict xb, xb
* graph amount xb years if itemcode==106 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==106 & years>10
replace amount=xb if amount==. & itemcode==106 & years>10
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==106 & years>10

* ksm amount years if itemcode==107, lowess
qreg amount years if itemcode==107
predict xb, xb
* graph amount xb years if itemcode==107, c(.l)
tab xb if amount==. & itemcode==107
drop xb

* ksm amount years if itemcode==108, lowess
* ksm amount years if itemcode==108 & amount<1000000, lowess
qreg amount years if itemcode==108 & years<=8
predict xb, xb
* graph amount xb years if itemcode==108 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==108 & years<=8
replace amount=xb if amount==. & itemcode==108 & years<=8
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==108 & years<=8
qreg amount years if itemcode==108 & years>8
predict xb, xb
* graph amount xb years if itemcode==108 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==108 & years>8
replace amount=xb if amount==. & itemcode==108 & years>8
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==108 & years>8

* ksm amount years if itemcode==109, lowess
qreg amount years if itemcode==109
predict xb, xb
* graph amount xb years if itemcode==109 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==109
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==109

* ksm amount years if itemcode==110, lowess
* ksm amount years if itemcode==110 & amount<1000000, lowess
qreg amount years if itemcode==110
predict xb, xb
* graph amount xb years if itemcode==110 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==110
replace amount=xb if amount==. & itemcode==110
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==110

* ksm amount years if itemcode==111, lowess
qreg amount years if itemcode==111
predict xb, xb
* graph amount xb years if itemcode==111, c(.l)
tab xb if amount==. & itemcode==111
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==111

* ksm amount years if itemcode==112, lowess
* ksm amount years if itemcode==112 & amount<400000 & years<50, lowess
qreg amount years if itemcode==112 & years<10
predict xb, xb
* graph amount xb years if itemcode==112 & amount<500000, c(.l)
tab xb if amount==. & itemcode==112 & years<10
replace amount=xb if amount==. & itemcode==112 & years<10
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==112 & years<10
qreg amount years if itemcode==112 & years>=10 & years<20
predict xb, xb
* graph amount xb years if itemcode==112 & amount<500000, c(.l)
tab xb if amount==. & itemcode==112 & years>=10 & years<20
replace amount=xb if amount==. & itemcode==112 & years>=10 & years<20
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==112 & years>=10 & years<20
qreg amount years if itemcode==112 & years>=20
predict xb, xb
* graph amount xb years if itemcode==112 & amount<500000, c(.l)
tab xb if amount==. & itemcode==112 & years>=20
replace amount=xb if amount==. & itemcode==112 & years>=20
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==112 & years>=20

* ksm amount years if itemcode==113, lowess
* ksm amount years if itemcode==113 & amount<500000, lowess
qreg amount years if itemcode==113 & years<15

* another difficult item, but here there are more observations, 750

* ksm amount years if itemcode==114, lowess
qreg amount years if itemcode==114
predict xb, xb
* graph amount xb years if itemcode==114, c(.l)
tab xb if amount==. & itemcode==114
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==114

* ksm amount years if itemcode==115, lowess
* ksm amount years if itemcode==115 & amount<500000, lowess
qreg amount years if itemcode==115 & years<=15
predict xb, xb
* graph amount xb years if itemcode==115 & amount<500000, c(.l)
tab xb if amount==. & itemcode==115 & years<=15
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==115 & years<=15
qreg amount years if itemcode==115 & years>15
predict xb, xb
* graph amount xb years if itemcode==115 & amount<500000, c(.l)
tab xb if amount==. & itemcode==115 & years>15
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==115 & years>15

* ksm amount years if itemcode==116, lowess
qreg amount years if itemcode==116
predict xb, xb
* graph amount xb years if itemcode==116, c(.l)
tab xb if amount==. & itemcode==116
replace amount=xb if amount==. & itemcode==116
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==116

* ksm amount years if itemcode==117, lowess
* ksm amount years if itemcode==117 & amount<500000, lowess
qreg amount years if itemcode==117
predict xb, xb
* graph amount xb years if itemcode==117 & amount<500000, c(.l)
tab xb if amount==. & itemcode==117
replace amount=xb if amount==. & itemcode==117
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==117

* ksm amount years if itemcode==118, lowess
* ksm amount years if itemcode==118 & amount<3000000, lowess
qreg amount years if itemcode==118
predict xb, xb
* graph amount xb years if itemcode==118 & amount<3000000, c(.l)
tab xb if amount==. & itemcode==118
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==118

* ksm amount years if itemcode==119, lowess
* ksm amount years if itemcode==119 & amount<1000000, lowess
qreg amount years if itemcode==119
predict xb, xb
* graph amount xb years if itemcode==119 & amount<1000000, c(.l)
tab xb if amount==. & itemcode==119
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==119

* ksm amount years if itemcode==120, lowess
* ksm amount years if itemcode==120 & amount<300000, lowess
qreg amount years if itemcode==120 & years<24
predict xb, xb
* graph amount xb years if itemcode==120 & amount<300000, c(.l)
tab xb if amount==. & itemcode==120 & years<24
replace amount=xb if amount==. & itemcode==120 & years<24
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==120 & years<24
qreg amount years if itemcode==120 & years>=24
predict xb, xb
* graph amount xb years if itemcode==120 & amount<300000, c(.l)
tab xb if amount==. & itemcode==120 & years>=24
replace amount=xb if amount==. & itemcode==120 & years>=24
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==120 & years>=24

* ksm amount years if itemcode==121, lowess
* ksm amount years if itemcode==121 & amount<2000000, lowess
qreg amount years if itemcode==121
predict xb, xb
* graph amount xb years if itemcode==121 & amount<2000000, c(.l)
tab xb if amount==. & itemcode==121
drop xb
replace deprate=-_b[years]/_b[_cons] if itemcode==121

* ksm amount years if itemcode==122, lowess
* ksm amount years if itemcode==122 & amount<10000000, lowess
qreg amount years if itemcode==122

* again for this item we are in serious problems, there are 364 observations

table itemcode, c(m deprate)

replace deprate=0.05 if itemcode==107
replace deprate=0.03 if itemcode==113
replace deprate=0.05 if itemcode==122

gen durcons=amount*deprate

* Comparing the different methodologies

* depreciation method

table itemcode, c(m durcons sd durcons med durcons max durcons)

* Lanjaow (2*sd)

table itemcode, c(m value1 sd value1 med value1 max value1)

* Lanjaow (3*sd)

table itemcode, c(m value2 sd value2 med value2 max value2)

* There are some big values, we need to check whether these big values come mainly from some few items or the problem is more general.

gen test=int(remlife1)
gen test1=int(remlife2)

table test if itemcode==101, c(m durcons m value1)
table test1 if itemcode==101, c(m durcons m value2)

table test if itemcode==102, c(m durcons m value1)
table test1 if itemcode==102, c(m durcons m value2)

table test if itemcode==103, c(m durcons m value1)
table test1 if itemcode==103, c(m durcons m value2)

table test if itemcode==104, c(m durcons m value1)
table test1 if itemcode==104, c(m durcons m value2)

table test if itemcode==105, c(m durcons m value1)
table test1 if itemcode==105, c(m durcons m value2)

table test if itemcode==106, c(m durcons m value1)
table test1 if itemcode==106, c(m durcons m value2)

table test if itemcode==107, c(m durcons m value1)
table test1 if itemcode==107, c(m durcons m value2)

table test if itemcode==108, c(m durcons m value1)
table test1 if itemcode==108, c(m durcons m value2)

table test if itemcode==109, c(m durcons m value1)
table test1 if itemcode==109, c(m durcons m value2)

table test if itemcode==110, c(m durcons m value1)
table test1 if itemcode==110, c(m durcons m value2)

table test if itemcode==111, c(m durcons m value1)
table test1 if itemcode==111, c(m durcons m value2)

table test if itemcode==112, c(m durcons m value1)
table test1 if itemcode==112, c(m durcons m value2)

table test if itemcode==113, c(m durcons m value1)
table test1 if itemcode==113, c(m durcons m value2)

table test if itemcode==114, c(m durcons m value1)
table test1 if itemcode==114, c(m durcons m value2)

table test if itemcode==115, c(m durcons m value1)
table test1 if itemcode==115, c(m durcons m value2)

table test if itemcode==116, c(m durcons m value1)
table test1 if itemcode==116, c(m durcons m value2)

table test if itemcode==117, c(m durcons m value1)
table test1 if itemcode==117, c(m durcons m value2)

table test if itemcode==118, c(m durcons m value1)
table test1 if itemcode==118, c(m durcons m value2)

table test if itemcode==119, c(m durcons m value1)
table test1 if itemcode==119, c(m durcons m value2)

table test if itemcode==120, c(m durcons m value1)
table test1 if itemcode==120, c(m durcons m value2)

table test if itemcode==121, c(m durcons m value1)
table test1 if itemcode==121, c(m durcons m value2)

table test if itemcode==122, c(m durcons m value1)
table test1 if itemcode==122, c(m durcons m value2)

table test if itemcode==125, c(m durcons m value1)
table test1 if itemcode==125, c(m durcons m value2)

* Considerably high numbers come especially from cars and motorcycles, but in all items there is a substantial problem in applying
* this methodology: it appears that when the item is particularly old the household is getting a higher benefit out of it. 

* The depreciation rate technique yields much better results.

rename durcons idurcons

keep hhid itemcode idurcons amount deprate value1 value2 
replace idurcons=idurcons/12
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durablesjm", replace

collapse (sum) durcons=idurcons, by(hhid)

replace durcons=durcons/12
sum durcons, d

sort hhid
gen year=2005
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durconsjm", replace

drop _all

log close
