/* Albania LSMS 2005, creating a consumption aggregate */

clear 
set more off
#delimit;

set mem 200M;
drop _all;


log using "lsms 2005 food", replace;


/* ************************************************************************** */
/* 	Now merge food, metadata and demographic files for subsequent cleaning 	*/
/* *************************************************************************** */
use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodwithcorrections.dta", clear;
sort hhid;

* merge metadata and household roster;
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\metadatafood.dta";
tab _merge;
drop _merge;
sort hhid;

merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\hhrosterdemog.dta";
sort code;
tab _merge;
drop _merge;

sort hhid;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodcons_cl.dta", replace;

drop _all;


/* ************************************************************** */
/* 	   Quick checks of data to see strange values		*/
/* ************************************************************** */

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodcons_cl.dta", clear;

* adjust quantity and unit of measure for food eaten out;
replace quantity=1 if quantity==. & type==3 & linenumitem!=.;
replace unit=3 if type==3 & linenumitem!=.;

* Simple checks:

count if unit==.;
egen umode=mode(unit), max by(hhid code);
list hhid code umode if unit==.;
drop if umode==.;

count if quantity==0 & value==.;
count if quantity!=. & value==.;
list code unit quantity value if quantity!=. & value==.;
count if quantity==. & value!=.;
list code unit quantity value if quantity==. & value!=.;
sum value quantity, d;
list code unit quantity value if quantity>9999 & quantity!=.;
recode periodofcons .=0 if type==2;
recode periodofcons .=0 if type==3;

* Replace errors in data entry;

count if quantity>9999 & quantity!=.;
replace quantity=. if quantity>9999 & quantity!=.;


*  Generate unit values;
gen uvalue=value/quantity;
egen euvalue1=median(uvalue), by(code unit psu);
egen euvalue2=median(uvalue), by(code unit district);
egen euvalue3=median(uvalue), by(code unit stratum);

* see whether we have any value to impute;
count if quantity==0 & value==.;
count if quantity!=. & value==.;
replace value=quantity*euvalue1 if quantity!=. & value==.;
replace value=quantity*euvalue2 if quantity!=. & value==. & euvalue1==.;
replace value=quantity*euvalue3 if quantity!=. & value==.& euvalue1==. & euvalue2==.;

count if quantity==. & value!=.;
replace quantity=value/euvalue1 if quantity==. & value!=.;
replace quantity=value/euvalue2 if quantity==. & euvalue1==. & value!=.;
replace quantity=value/euvalue3 if quantity==. & euvalue1==. & euvalue2==. & value!=.;

count if quantity==0 & value==0;
count if quantity==0 & value!=0;
replace quantity=value/euvalue1 if quantity==0 & value!=0;
replace quantity=value/euvalue2 if quantity==0 &euvalue1==. & value!=.;
replace quantity=value/euvalue3 if quantity==0 & euvalue1==. & euvalue2==. & value!=.;

count if quantity!=0 & value==0;

* Replace unit values for the cases it was missing;
replace uvalue=value/quantity if uvalue==.;


/* ********************************************* */
/*	Establish relation between period 	 */
/*	of consumption and value of expenditures */
/* ********************************************* */

sort type;

* by type: table itc periodofcons, c(mean value median value);

* confirm with a regression line;

sort itc;

*reg value periodofcons, robust cluster(itc); 
*xtreg value periodofcons, fe i(itc);
*xtreg value periodofcons, re i(itc);


/* ************************************************************************* */
/* Note: standardize value - convert all expenditures to two-weekly expenditures */
/* Note that periodofcons with code 5 (more than a month), */
/* was assumed to be 3 months; For checklist, the codes are different --  */
/* 1 means (15 days), 2 means (1 month), 3 means (2 months), 4 means (a quarter) */
/* and 5 means (rarely--we assume once every 6 months)				 */
/* ***************************************************************************** */

* generate a new periodofcons;

gen periodcons=periodofcons;
replace periodcons=6 if periodofcons==1&type==0;
replace periodcons=7 if periodofcons==2&type==0;
replace periodcons=8 if periodofcons==3&type==0;
replace periodcons=9 if periodofcons==4&type==0;
replace periodcons=10 if periodofcons==5&type==0;

* Now convert food expenditures into two-week expenditures;
gen foodexp=value;
replace foodexp=value/2 if periodcons==4 & type==1; /* month to 2 weeks */
replace foodexp=value/6 if periodcons==5 & periodcons!=. & type==1; /* more than month to 2 weeks */

* for items in the checklist, here is the adjustment;
replace foodexp=value/2 if periodcons==7 & type==0; /* month to 2 weeks */
replace foodexp=value/4 if periodcons==8 & type==0;/* 2 month to 2 weeks */
replace foodexp=value/6 if periodcons==9 & type==0;/* quarter to 2 weeks */
replace foodexp=value/12 if periodcons==10 & type==0;/* rarely to 2 weeks */


* Similarly standardize all quantities to two-week quantities;
gen newquant=quantity;
replace newquant=quantity/2 if periodcons==4 & type==1;
replace newquant=quantity/6 if periodcons>=5 & periodcons!=. & type==1;

replace newquant=quantity/2 if periodcons==7 & type==0;
replace newquant=quantity/4 if periodcons==8 & type==0;
replace newquant=quantity/6 if periodcons==9 & type==0;
replace newquant=quantity/12 if periodcons==10 & type==0;

sort hhid code date type;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodcons_cl.dta", replace;


/* *************************************************************  */
/* Create main food sub-groups: bread, cereals, meat, fish, milk, */
/* oil, fruits, vegetables, conserved, sugar, spices, beverages,  */
/* other, food eaten out					  */
/* *************************************************************  */

sort code;
by code: gen itemct=_n;
egen itemcount=max(itemct), by(code);
egen uniquecode=tag(code);
drop if uniquecode!=1;
keep code itc itemname uniquecode itemcount;
gen code2005=code;
sort code;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\subgroups.dta", replace;
drop _all;

* sort the groups data;
use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\subgroups05.dta", clear;
sort code subgrp;
keep code subgrp;
sort code;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\subgroups05_clsorted.dta", replace;
drop _all;



/* ***************************************************************** */
/* Bring in sub-groups, merge to food file and then check outliers.   */
/* *****************************************************************  */

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodcons_cl.dta", clear;
sort code;

merge code using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\subgroups05_clsorted.dta";
tab _merge;
drop _merge;
sort hhid code;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodconswithgrps_cl.dta", replace;
drop _all;


/* ******************************************************************** */
/* 1. Basic cleaning: check food groups that have large expenditures    */
/* Check for outliers if group shares exceed 2 sd, except grp 14 (foodout) */
/* ******************************************************************   */

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodconswithgrps_cl.dta", clear;
egen foodcons=sum(foodexp), by(hhid);
egen grpexp=sum(foodexp), by(hhid subgrp);
gen grpsh=grpexp/foodcons;
egen mgrpsh=mean(grpsh), by(subgrp);
egen sdgrpsh=sd(grpsh), by(subgrp);
gen sdflag=(grpsh-mgrpsh)/sdgrpsh;
gen sdrule=sdflag > 2 & sdflag!=.;

sort hhid subgrp code;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodconsall.dta", replace;


/* ******************************************************************* */
/* Check for outliers if per capita item exp exceed 5 times median per */
/* capita spending for that item (nationally or by urban/rural?)       */
/* ******************************************************************* */

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodconsall.dta", replace;

* We will clean food purchased outside differently, so here we drop it;
drop if subgrp==14;

count if abs(sdflag)>2;

* list hhid code sdflag itcstr grpsh if abs(sdflag) > 2;


/* ************************************************************** */
/* Compute medians of exp, quantities and unitvalues (prices)     */
/*  to flag outliers sort hhid itc code                           */
/* ************************************************************** */

* Generate median item expenditure;
egen totitemexp=sum(foodexp), by(hhid itc);
gen pcitemexp=totitemexp/acthhsize;
egen meditexppsu=median(pcitemexp), by(itc psu);
egen meditexpdis=median(pcitemexp), by(itc district);
egen meditexpstr=median(pcitemexp), by(itc stratum);

* generate median quantities;
egen totitemquant=sum(newquant), by(hhid itc);
gen pcquant=totitemquant/acthhsize;
egen medquantpsu=median(pcquant), by(itc psu);
egen medquantdis=median(pcquant), by(itc district);
egen medquantstr=median(pcquant), by(itc stratum);

* Generate median unit values;
gen pcuvalue=pcitemexp/pcquant;  /* same as unit value - uvalue */
egen meduvpsu=median(pcuvalue), by(itc psu);
egen meduvdis=median(pcuvalue), by(itc district);
egen meduvstr=median(pcuvalue), by(itc stratum);

* Generate median to compare to outliers;
egen meditcexpc=median(pcitemexp), by(urbrur itc);
egen meditcquantpc=median(pcquant), by(urbrur itc);
egen meduvalue=median(pcuvalue), by(urbrur itc);
egen medhhsize=median(acthhsize);
egen meditcexp=median(totitemexp), by(urbrur itc);
egen meditcquant=median(totitemquant), by(urbrur itc);
egen meditcuv=median(uvalue), by(urbrur itc);

* expenditure outliers;
gen testhighexp=pcitemexp>5*meditcexpc;
* quantity outliers;
gen testhighquant=pcquant>5*meditcquantpc;
* uvalue outliers;
gen testhighuv=pcuvalue>5*meduvalue;


/* *********************************************************   */
/* We also check transaction specific outliers, and check      */
/* if the results will differ much 				*/
/* ********************************************************	*/
gen itcexppc=foodexp/acthhsize;
gen qitcpc=newquant/acthhsize;
gen uvpc=itcexppc/qitcpc;

* Generate median transaction specific unit values;
egen muvpsu=median(uvpc), by(itc psu);
egen muvdis=median(uvpc), by(itc district);
egen muvstr=median(uvpc), by(itc stratum);

* Generate median item expenditure;
egen mitcexppsu=median(itcexppc), by(itc psu);
egen mitcexpdis=median(itcexppc), by(itc district);
egen mitcexpstr=median(itcexppc), by(itc stratum);

* generate median quantities;
egen mqitcpsu=median(qitcpc), by(itc psu);
egen mqitcdis=median(qitcpc), by(itc district);
egen mqitcstr=median(qitcpc), by(itc stratum);

* Generate median to compare to outliers;
egen mitcexpc=median(itcexppc), by(urbrur itc);
egen mitcqpc=median(qitcpc), by(urbrur itc);
egen muvpc=median(uvpc), by(urbrur itc);

* expenditure outliers;
gen exptest2=itcexppc>5*mitcexpc;
* quantity outliers;
gen qtest2=qitcpc>5*mitcqpc;
* uvalue outliers;
gen uvtest2=uvpc>5*muvpc;


/* *************************************************************** */
/* Identify cases of outlier combinations and replace with medians */
/* *************************************************************** */

* First count the number of each item by households;
gen itcid=1;
egen itcsum=sum(itcid), by(hhid itc);

* Now count the number of purchases for each item;
egen itcpsu=count(value) if value>0 & value!=., by(itc psu);
egen itcdist=count(value) if value>0 & value!=., by(itc district);
egen itcstr=count(value) if value>0 & value!=., by(itc stratum);


/*
* Table identifies if purchases of an item are too few to compute price;
table itc, c(min itcpsu median itcpsu max itcpsu);
table itc, c(min itcdist median itcdist max itcdist);
table itc, c(min itcstr median itcstr max itcstr);
*/


* First flag locations with few purchases;
gen purcount=.;
replace purcount=1 if itcpsu>=10;
replace purcount=2 if itcpsu<10 & itcdist>=10;
replace purcount=3 if itcpsu < 10 & itcdist<10 & itcstr>=10;
replace purcount=4 if itcpsu < 10 & itcdist < 10 & itcstr < 10;
recode purcount .=5;

tab purcount;

* Generate outlier flags;

* expenditure flags - high only;
gen expflagh=sdrule==1 & testhighexp==1;
gen expitcout=sdrule==1 &exptest2==1;

* quantity flags - high only;
gen qflagh = sdrule==1 & testhighquant==1;
gen qitcout= sdrule==1 & qtest2==1;

* Unit value flags - high only;
gen uvflagh = sdrule==1 & testhighuv==1;
gen uvitcout=sdrule==1 & uvtest2==1;

* Possible combination of outliers;
gen outcase=0;
replace outcase=1 if expflagh==1 & qflagh==1&uvflagh==1;
replace outcase=2 if expflagh==1 & qflagh==1&uvflagh==0;
replace outcase=3 if expflagh==1 & qflagh==0&uvflagh==1;
replace outcase=4 if expflagh==1 & qflagh==0&uvflagh==0;
replace outcase=5 if expflagh==0 & qflagh==1&uvflagh==1;
replace outcase=6 if expflagh==0 & qflagh==1&uvflagh==0;
replace outcase=7 if expflagh==0 & qflagh==0&uvflagh==1;
gen correct=outcase>0 & outcase!=.;

tab outcase;

gen itccase=0;
replace itccase=1 if expitcout==1 & qitcout==1 & uvitcout==1;
replace itccase=2 if expitcout==1 & qitcout==1 & uvitcout==0;
replace itccase=3 if expitcout==1 & qitcout==0 & uvitcout==1;
replace itccase=4 if expitcout==1 & qitcout==0 & uvitcout==0;
replace itccase=5 if expitcout==0 & qitcout==1 & uvitcout==1;
replace itccase=6 if expitcout==0 & qitcout==1 & uvitcout==0;
replace itccase=7 if expitcout==0 & qitcout==0 & uvitcout==1;


tab itccase;


/* ******************************************************************** */
/* After checking the questionnaires of several identified 		*/
/* outliers the team concluded that the data seemed reasonable and	*/ 
/* may reflect household heterogeneity -- habits. Replacing the 	*/
/* identified outliers will not change much. Entire outliers are	*/ 
/* less than 0.25% of observations. However, some households		*/ 	
/* misreported flour consumed and we correct that below  		*/
/* *******************************************************************	*/

* compute the correct quantities of flour for problem cases;
replace quantity=qtyflour-qtyforbread if quantity==qtyflour & code=="11132" & itccase>0;
replace quantity=max(qtyflour,quantity)-qtyforbread if quantity!=qtyflour & code=="11132" & itccase>0;
replace periodcons=4 if periodcons!=4&code=="11132"&type==1&itccase>0;
replace periodcons=7 if periodcons!=7&code=="11132"&type==0&itccase>0;

sort hhid code;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\foodtemp.dta", replace;


/* ****************************************************************************************** */

/* *************************************************************************************** */
/* Now we do the whole thing again to see the number of outliers and correct them 	*/
/* ***********************************************************************************	*/

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\foodtemp.dta", replace;

keep hhid code itc itemname value quantity unit umode periodcons type date psu district prefecture stratum urbrur area acthhsize weight itccase sdrule subgrp;

gen uvalue=value/quantity;

* Now convert food expenditures into two-week expenditures;
gen foodexp=value;
replace foodexp=value/2 if periodcons==4 & type==1; /* month to 2 weeks */
replace foodexp=value/6 if periodcons==5 & periodcons!=. & type==1; /* more than month to 2 weeks */

* for items in the checklist, here is the adjustment;
replace foodexp=value/2 if periodcons==7 & type==0; /* month to 2 weeks */
replace foodexp=value/4 if periodcons==8 & type==0;/* 2 month to 2 weeks */
replace foodexp=value/6 if periodcons==9 & type==0;/* quarter to 2 weeks */
replace foodexp=value/12 if periodcons==10 & type==0;/* rarely to 2 weeks */


* Similarly standardize all quantities to two-week quantities;
gen newquant=quantity;
replace newquant=quantity/2 if periodcons==4 & type==1;
replace newquant=quantity/6 if periodcons>=5 & periodcons!=. & type==1;

replace newquant=quantity/2 if periodcons==7 & type==0;
replace newquant=quantity/4 if periodcons==8 & type==0;
replace newquant=quantity/6 if periodcons==9 & type==0;
replace newquant=quantity/12 if periodcons==10 & type==0;

* We have to adjust a few flour quantities in own consumption because they are monthly;
replace newquant=quantity/2 if code=="11132" & type==2 & itccase>0;
drop itccase;
sort hhid code date type;

/* ************************************************************** */
/* Compute medians of exp, quantities and unitvalues (prices)     */
/*  to flag outliers sort hhid itc code                           */
/* ************************************************************** */

* Generate median item expenditure;
egen totitemexp=sum(foodexp), by(hhid itc);
gen pcitemexp=totitemexp/acthhsize;
egen meditexppsu=median(pcitemexp), by(itc psu);
egen meditexpdis=median(pcitemexp), by(itc district);
egen meditexpstr=median(pcitemexp), by(itc stratum);

* generate median quantities;
egen totitemquant=sum(newquant), by(hhid itc);
gen pcquant=totitemquant/acthhsize;
egen medquantpsu=median(pcquant), by(itc psu);
egen medquantdis=median(pcquant), by(itc district);
egen medquantstr=median(pcquant), by(itc stratum);

* Generate median unit values;
gen pcuvalue=pcitemexp/pcquant;  /* same as unit value - uvalue */
egen meduvpsu=median(pcuvalue), by(itc psu);
egen meduvdis=median(pcuvalue), by(itc district);
egen meduvstr=median(pcuvalue), by(itc stratum);

* Generate median to compare to outliers;
egen meditcexpc=median(pcitemexp), by(urbrur itc);
egen meditcquantpc=median(pcquant), by(urbrur itc);
egen meduvalue=median(pcuvalue), by(urbrur itc);
egen medhhsize=median(acthhsize);
egen meditcexp=median(totitemexp), by(urbrur itc);
egen meditcquant=median(totitemquant), by(urbrur itc);
egen meditcuv=median(uvalue), by(urbrur itc);

* expenditure outliers;
gen testhighexp=pcitemexp>5*meditcexpc;
* quantity outliers;
gen testhighquant=pcquant>5*meditcquantpc;
* uvalue outliers;
gen testhighuv=pcuvalue>5*meduvalue;


/* *********************************************************   */
/* We also check transaction specific outliers, and check      */
/* if the results will differ much 				*/
/* ********************************************************	*/
gen itcexppc=foodexp/acthhsize;
gen qitcpc=newquant/acthhsize;
gen uvpc=itcexppc/qitcpc;

* Generate median transaction specific unit values;
egen muvpsu=median(uvpc), by(itc psu);
egen muvdis=median(uvpc), by(itc district);
egen muvstr=median(uvpc), by(itc stratum);

* Generate median item expenditure;
egen mitcexppsu=median(itcexppc), by(itc psu);
egen mitcexpdis=median(itcexppc), by(itc district);
egen mitcexpstr=median(itcexppc), by(itc stratum);

* generate median quantities;
egen mqitcpsu=median(qitcpc), by(itc psu);
egen mqitcdis=median(qitcpc), by(itc district);
egen mqitcstr=median(qitcpc), by(itc stratum);

* Generate median to compare to outliers;
egen mitcexpc=median(itcexppc), by(urbrur itc);
egen mitcqpc=median(qitcpc), by(urbrur itc);
egen muvpc=median(uvpc), by(urbrur itc);

* expenditure outliers;
gen exptest2=itcexppc>5*mitcexpc;
* quantity outliers;
gen qtest2=qitcpc>5*mitcqpc;
* uvalue outliers;
gen uvtest2=uvpc>5*muvpc;


/* *************************************************************** */
/* Identify cases of outlier combinations and replace with medians */
/* *************************************************************** */

* First count the number of each item by households;
gen itcid=1;
egen itcsum=sum(itcid), by(hhid itc);

* Now count the number of purchases for each item;
egen itcpsu=count(value) if value>0 & value!=., by(itc psu);
egen itcdist=count(value) if value>0 & value!=., by(itc district);
egen itcstr=count(value) if value>0 & value!=., by(itc stratum);


/*
* Table identifies if purchases of an item are too few to compute price;
table itc, c(min itcpsu median itcpsu max itcpsu);
table itc, c(min itcdist median itcdist max itcdist);
table itc, c(min itcstr median itcstr max itcstr);
*/


* First flag locations with few purchases;
gen purcount=.;
replace purcount=1 if itcpsu>=10;
replace purcount=2 if itcpsu<10 & itcdist>=10;
replace purcount=3 if itcpsu < 10 & itcdist<10 & itcstr>=10;
replace purcount=4 if itcpsu < 10 & itcdist < 10 & itcstr < 10;
recode purcount .=5;

tab purcount;

* Generate outlier flags;

* expenditure flags - high only;
gen expflagh=sdrule==1 & testhighexp==1;
gen expitcout=sdrule==1 &exptest2==1;

* quantity flags - high only;
gen qflagh = sdrule==1 & testhighquant==1;
gen qitcout= sdrule==1 & qtest2==1;

* Unit value flags - high only;
gen uvflagh = sdrule==1 & testhighuv==1;
gen uvitcout=sdrule==1 & uvtest2==1;

* Possible combination of outliers;
gen outcase=0;
replace outcase=1 if expflagh==1 & qflagh==1&uvflagh==1;
replace outcase=2 if expflagh==1 & qflagh==1&uvflagh==0;
replace outcase=3 if expflagh==1 & qflagh==0&uvflagh==1;
replace outcase=4 if expflagh==1 & qflagh==0&uvflagh==0;
replace outcase=5 if expflagh==0 & qflagh==1&uvflagh==1;
replace outcase=6 if expflagh==0 & qflagh==1&uvflagh==0;
replace outcase=7 if expflagh==0 & qflagh==0&uvflagh==1;
gen correct=outcase>0 & outcase!=.;

tab outcase;

gen itccase=0;
replace itccase=1 if expitcout==1 & qitcout==1 & uvitcout==1;
replace itccase=2 if expitcout==1 & qitcout==1 & uvitcout==0;
replace itccase=3 if expitcout==1 & qitcout==0 & uvitcout==1;
replace itccase=4 if expitcout==1 & qitcout==0 & uvitcout==0;
replace itccase=5 if expitcout==0 & qitcout==1 & uvitcout==1;
replace itccase=6 if expitcout==0 & qitcout==1 & uvitcout==0;
replace itccase=7 if expitcout==0 & qitcout==0 & uvitcout==1;
gen correct2=itccase>0&itccase!=.;

tab itccase;

*replace quantities that are very high;
gen modpcquant=pcquant;
replace modpcquant=meditcquantpc if outcase==1 & (purcount==4 | purcount==5);
replace modpcquant=medquantpsu if outcase==1 & purcount==1;
replace modpcquant=medquantdis if outcase==1 & purcount==2;
replace modpcquant=medquantstr if outcase==1 & purcount==3;

replace modpcquant=meditcquantpc if outcase==2 & (purcount==4 | purcount==5);
replace modpcquant=medquantpsu if outcase==2 & purcount==1;
replace modpcquant=medquantdis if outcase==2 & purcount==2;
replace modpcquant=medquantstr if outcase==2 & purcount==3;

replace modpcquant=meditcquantpc if outcase==6 & (purcount==4 | purcount==5);
replace modpcquant=medquantpsu if outcase==6 & purcount==1;
replace modpcquant=medquantdis if outcase==6 & purcount==2;
replace modpcquant=medquantstr if outcase==6 & purcount==3;

replace modpcquant=(meditcquant/medhhsize) if medquantpsu==. | medquantdis==. | medquantstr==.;

* Replace unit values that are far too high;
gen modpcuvalue=pcuvalue;
replace modpcuvalue=meduvalue if outcase==1 & (purcount==4 | purcount==5);
replace modpcuvalue=meduvpsu if outcase==1 & purcount==1;
replace modpcuvalue=meduvdis if outcase==1 & purcount==2;
replace modpcuvalue=meduvstr if outcase==1 & purcount==3;
replace modpcuvalue=meduvalue if meduvpsu==. | meduvdis==. | meduvstr==.;

replace modpcuvalue=meduvalue if outcase==3 & (purcount==4 | purcount==5);
replace modpcuvalue=meduvpsu if outcase==3 & purcount==1;
replace modpcuvalue=meduvdis if outcase==3 & purcount==2;
replace modpcuvalue=meduvstr if outcase==3 & purcount==3;
replace modpcuvalue=meduvalue if meduvpsu==. | meduvdis==. | meduvstr==.;


* replace expenditures that are too high;
gen modexpc=pcitemexp;
replace modexpc=meditcexpc if outcase==4 & (purcount==4 | purcount==5);
replace modexpc=meditexppsu if outcase==4 & purcount==1;
replace modexpc=meditexpdis if outcase==4 & purcount==2;
replace modexpc=meditexpstr if outcase==4 & purcount==3;

replace modexpc=meditcexpc if outcase==7 & (purcount==4 | purcount==5);
replace modexpc=meditexppsu if outcase==7 & purcount==1;
replace modexpc=meditexpdis if outcase==7 & purcount==2;
replace modexpc=meditexpstr if outcase==7 & purcount==3;

replace modexpc=(meditcexp/medhhsize) if meditexppsu==. | meditexpdis==. | meditexpstr==.;

* Now we create a new expenditure (in per capita terms);

gen newitemexpc=modexpc;
replace newitemexpc=modpcquant*modpcuvalue if outcase==1 | outcase==2 | outcase==3 | outcase==6;

* Convert all to values;
gen newval=foodexp;
replace newval=((newitemexpc*acthhsize)/itcsum) if correct==1;

* obtain quantities;
gen nquant=newquant;
replace nquant=((modpcquant*acthhsize)/itcsum) if correct==1;

tab correct;
count if newitemexpc==0 | newitemexpc==.;
count if newval==0 | newval==1;


/*

*replace quantities that are very high;
gen modqitc=qitcpc;
replace modqitc=mitcqpc if itccase==1 & (purcount==4 | purcount==5);
replace modqitc=mqitcpsu if itccase==1 & purcount==1;
replace modqitc=mqitcdis if itccase==1 & purcount==2;
replace modqitc=mqitcstr if itccase==1 & purcount==3;

replace modqitc=mitcqpc if itccase==2 & (purcount==4 | purcount==5);
replace modqitc=mqitcpsu if itccase==2 & purcount==1;
replace modqitc=mqitcdis if itccase==2 & purcount==2;
replace modqitc=mqitcstr if itccase==2 & purcount==3;

replace modqitc=mitcqpc if itccase==6 & (purcount==4 | purcount==5);
replace modqitc=mqitcpsu if itccase==6 & purcount==1;
replace modqitc=mqitcdis if itccase==6 & purcount==2;
replace modqitc=mqitcstr if itccase==6 & purcount==3;


replace modqitc=(mitcqpc/medhhsize) if mqitcpsu==. | mqitcdis==. | mqitcstr==.;

* Replace unit values that are far too high;
gen moditcuv=uvpc;
replace moditcuv=muvpc if itccase==1 & (purcount==4 | purcount==5);
replace moditcuv=muvpsu if itccase==1 & purcount==1;
replace moditcuv=muvdis if itccase==1 & purcount==2;
replace moditcuv=muvstr if itccase==1 & purcount==3;
replace moditcuv=muvpc if muvpsu==. | muvdis==. | muvstr==.;

replace moditcuv=muvpc if itccase==3 & (purcount==4 | purcount==5);
replace moditcuv=muvpsu if itccase==3 & purcount==1;
replace moditcuv=muvdis if itccase==3 & purcount==2;
replace moditcuv=muvstr if itccase==3 & purcount==3;
replace moditcuv=muvpc if muvpsu==. | muvdis==. | muvstr==.;


* replace expenditures that are too high;
gen moditcex=itcexppc;
replace moditcex=mitcexpc if itccase==4 & (purcount==4 | purcount==5);
replace moditcex=mitcexppsu if itccase==4 & purcount==1;
replace moditcex=mitcexpdis if itccase==4 & purcount==2;
replace moditcex=mitcexpstr if itccase==4 & purcount==3;

replace moditcex=mitcexpc if itccase==7 & (purcount==4 | purcount==5);
replace moditcex=mitcexppsu if itccase==7 & purcount==1;
replace moditcex=mitcexpdis if itccase==7 & purcount==2;
replace moditcex=mitcexpstr if itccase==7 & purcount==3;

replace moditcex=(mitcexpc/medhhsize) if mitcexppsu==. | mitcexpdis==. | mitcexpstr==.;

* Now we create a new expenditure (in per capita terms);

gen newitemexpc=moditcex;
replace newitemexpc=modqitc*moditcuv if itccase==1 | itccase==2 | itccase==3 | itccase==6;

* Convert all to values;
gen newval=foodexp;
replace newval=(newitemexpc*acthhsize) if correct==1;

* obtain quantities;
gen nquant=newquant;
replace nquant=((modqitc*acthhsize)) if correct==1;

tab correct;
count if newitemexpc==0 | newitemexpc==.;
count if newval==0 | newval==1;

*/

sum pcitemexp newitemexpc newval newquant nquant;

sort hhid code;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodnoutliers_cl.dta", replace;
drop _all;


/* ************************************************************ */
/* Now we do adjustments to food eaten out, that is subgroup 14 */
/* ************************************************************ */

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodconsall.dta", clear;

keep if subgrp==14;

duplicates report;
egen medfout=median(foodexp), by(hhid itc);
gen testfout=foodexp>10*medfout;
gen newval=foodexp;
replace newval=foodexp/10 if testfout==1;
sort hhid code;

save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodoutnoutliers_cl.dta", replace;
drop _all;


/* ************************************************************************************ */


/* ************************************************************************************* */
/* Append/Merge cleaned food consumption to obtain total food.				*/
/* Also, compute prices	across the four strata and location (rural/urban) --separate file. */
/* *************************************************************************************** */


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodnoutliers_cl.dta", clear;
sort hhid code;

merge hhid code using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodoutnoutliers_cl.dta";

save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodforprices.dta", replace;


/* ******************************************************************** */
/*  First, obtain total food expenditures 				*/
/* ******************************************************************** */

* we create total item expenditure, and also food expenditures (monthly);
egen food=sum(newval), by(hhid);
egen food1=sum(foodexp), by(hhid);
* Now tag households and drop duplicates;
egen hhdtag=tag(hhid);
drop if hhdtag!=1;

collapse (mean) food food1 maxhhsize acthhsize, by(hhid);
replace food=food*2.17;
replace food1=food1*2.17;
keep hhid food food1 maxhhsize acthhsize;
sort hhid;
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodexp.dta", replace;

drop _all;
log close;


