*** Paasche price index for psu

clear
set more off
set mem 200m

log using psupricesrep, replace

** Program to calculate the Paasche Index by psu

** 0. To make sure that each household consumes at least 5 different food items
** 1. To obtain the budget share of each food item per psu
** 2. To obtain the implicit price paid for each food item per psu
** 3. To obtain the reference price (median price of each food item at national level)
** 4. To normalize and calculate the index: sum of (1*ln(2/3))

** 0.

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\preparedprices.dta", clear
gen one=1
egen nobs=sum(one), by(hhid)
count if nobs==.
tab nobs if nobs<30
* ok!

collapse (mean) area, by(psu)
tab area
* we have 480 psu, we should make sure that these are kept

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\hhrosterdemog", clear
rename acthhsize hhsize
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\preparedprices"
tab _merge
keep if _merge==3
drop _merge
collapse (mean) stratum prefecture urbrur area psu weight hhsize, by(hhid)
gen pweight=weight*hhsize
egen totpop=sum(pweight)
egen pop_pr=sum(pweight), by(stratum urbrur)
egen pop_psu=sum(pweight), by(psu)
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", replace

gen one=1
collapse (sum) one, by(psu)
summ one
* ok, we have 480 psu

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", clear
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\preparedprices"
tab _merge
drop _merge
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\tempor", replace


** 1.

* calculate budget shares (average by population)
use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\tempor", clear
rename newval consi
label var consi "Consumption per item"
egen double const=sum(consi), by(hhid)
label var const "Total Consumption per household"
gen double wi=consi/const
replace wi=wi*pweight
collapse (sum) wi (mean) pop_psu weight stratum urbrur area, by(psu itc)
gen wipsu=wi/pop_psu
label var wipsu "Budget share of item by psu"
summ
* just to check
egen totsh=sum(wipsu), by(psu)
summ totsh
compress
drop totsh wi
sort psu itc
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", replace

** 2.

* calculate median prices by psu
use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\tempor", clear
collapse (mean) psuprice weight stratum urbrur area, by(psu itc)
label var psuprice "Implicit price per food item per psu"
summ
compress
sort psu itc
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp2", replace

** 3.

* to calculate the price of each food item at a national level using weights
use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\tempor", clear
drop p0
collapse (mean) p0=psuprice [pweight=weight], by(itc)
label var p0 "Price of each food item (national level)"
summ
compress
sort itc
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp3", replace

clear
set mem 100m

** 4.

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", clear
merge psu itc using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp2"
tab _merge
drop _merge
sort itc
merge itc using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp3"
tab _merge
drop _merge
sort psu itc
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\bshares", replace
gen double lnindex= wipsu*log(psuprice/p0)
collapse (sum) lnindex (mean) weight stratum urbrur area, by(psu)
gen psupind=exp(lnindex)
label var psupind "Paasche Index by psu"
drop lnindex
summ
sort psu
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp4", replace


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp"
sort psu
merge psu using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp4"
tab _merge
drop _merge
sum psupind [aweight=weight]
gen norm=_result(3)
replace psupind=psupind/norm
label var  psupind "Paasche Index by Household (normalized)"
drop norm
compress
keep hhid psu psupind stratum urbrur weight area
sort psu
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\psupindrep.dta", replace
* to obtain the average Paasche Index by region (urban/rural) and province
table stratum urbrur [pweight=weight], c(mean psupind) row col
table area [pweight=weight], c(mean psupind) row col
table stratum urbrur [aweight=weight], c(mean psupind) row col

! del "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp*.dta"

drop _all
log close
