*** This file aggregates all consumption sources and checks for outliers with the "budget share method".

clear
set more off
set matsize 700
set mem 100m

log using totconsjm, replace

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodexp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfoodexp"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\eduexp"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilitiesjm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durablesjm"
tab _merge
drop _merge

egen edu=rsum(eduexp02 preschool suptextbook excursion)
egen fuel=rsum(firewood-other)
egen phone=rsum(phonebill mobile)
egen totcons=rsum(food sub1-sub10 edu elect fuel waterb phone idurcons)
egen totcons5=rsum(food sub1-sub11 edu elect fuel waterb phone computerbill idurcons)

for var food food1 sub1-sub11 edu elect fuel water phone computerbill idurcons: recode X 0=.

* now we compute shares

gen fodsh=food/totcons
local i=1
while `i'<=11 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=idurcons/totcons
gen phosh=phone/totcons
gen comsh=computerbill/totcons

* Just to check
egen tot=rsum(fodsh-phosh)
sum tot
drop tot

sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace

*** Check durables

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp.dta", clear
egen mdsh=mean(dursh)
egen sddsh=sd(dursh)
gen test=1 if (dursh>mdsh+2*sddsh) & dursh!=.
count if test==1
sum dursh if test==1, d
keep if test==1
keep hhid food totcons test dursh acthhsize
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", replace


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durablesjm", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp"
tab _merge
keep if _merge==3
drop _merge
gen durpc=idurcons/acthhsize
egen mean=mean(durpc), by(itemcode)
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1"
tab _merge
gen share=idurcons/totcons
egen max=max(share), by(hhid)
gen test1=(idurcons/acthhsize)/mean
count if test1>10 & max==share & _merge==3
count if test1>5 & max==share & _merge==3
tab itemcode if test1>5 & max==share & _merge==3
list hhid itemcode idurcons amount dursh share test1 if test1>5 & max==share & _merge==3
gen correct=1 if test1>5 & max==share & _merge==3
gen idurcons1=idurcons
replace idurcons1=((amount/10)*deprate) if correct==1
keep hhid itemcode idurcons idurcons1 amount deprate
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durables1jm", replace
gen durcons=idurcons1
collapse (sum) durcons, by(hhid)
sum durcons, d
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durcons1jm", replace


*** After these corrections we recalculate again total consumption

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodexp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfoodexp"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\eduexp"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilitiesjm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durcons1jm"
tab _merge
drop _merge

egen edu=rsum(eduexp02 preschool suptextbook excursion)
egen fuel=rsum(firewood-other)
egen phone=rsum(phonebill mobile)
egen totcons=rsum(food sub1-sub10 edu elect fuel waterb phone durcons)
egen totcons05=rsum(food sub1-sub11 edu elect fuel waterb computerbill phone durcons)

for var food sub1-sub11 edu elect fuel water phone computerbill durcons: recode X 0=.

* now we compute shares

gen fodsh=food/totcons
local i=1
while `i'<=11 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
gen comsh=computerbill/totcons

* Just to check
egen tot=rsum(fodsh-comsh)
sum tot
drop tot
* drop test
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace


*** Check all the subgroups of non food

local i=1
while `i'<=11 {
use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
egen mssh`i'=mean(ssh`i')
egen sdssh`i'=sd(ssh`i')
gen test=1 if (ssh`i'>mssh`i'+2*sdssh`i') & ssh`i'!=.
count if test==1
sum ssh`i' if test==1, d
keep if test==1
keep hhid food totcons test ssh`i' acthhsize
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", replace

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfood", clear
keep if subgroup==`i'
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp"
tab _merge
drop if _merge==2
drop _merge
gen nfoodpc=nfood/acthhsize
egen meanf=mean(nfoodpc), by(code)
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1"
tab _merge
gen share=nfood/totcons
egen max=max(share), by(hhid)
gen test1=(nfood/acthhsize)/meanf
count if test1>10 & max==share & _merge==3
tab code if test1>10 & max==share & _merge==3
list hhid code nfood ssh`i' share test1 if test1>10 & max==share & _merge==3
gen correct=1 if test1>10 & max==share & _merge==3
gen nfood1=nfood
replace nfood1=nfood1/10 if test1>10 & max==share & _merge==3
keep code hhid nfood nfood1 subgroup correct
sort hhid code
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\group`i'", replace
local i=`i'+1
}

* we build again non food expenses

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\group1", clear
local i=2
while `i'<=11 {
sort hhid code
merge hhid code using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\group`i'"
tab _merge
drop _merge
local i=`i'+1
}

sort hhid code
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace

collapse (sum) nfood=nfood1, by(hhid subgroup)

gen sub1=nfood if subgroup==1
gen sub2=nfood if subgroup==2
gen sub3=nfood if subgroup==3
gen sub4=nfood if subgroup==4
gen sub5=nfood if subgroup==5
gen sub6=nfood if subgroup==6
gen sub7=nfood if subgroup==7
gen sub8=nfood if subgroup==8
gen sub9=nfood if subgroup==9
gen sub10=nfood if subgroup==10
gen sub11=nfood if subgroup==11

collapse (sum) sub1-sub11, by(hhid)
egen nfood=rsum(sub1-sub10)
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfoodexp1", replace


*** After these corrections we recalculate again total consumption

clear 
set mem 20m

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodexp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfoodexp1"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\eduexp"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilitiesjm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durcons1jm"
tab _merge
drop _merge

egen edu=rsum(eduexp02 preschool suptextbook excursion)
egen fuel=rsum(firewood-other)
egen phone=rsum(phonebill mobile)
egen totcons=rsum(food sub1-sub10 edu elect fuel waterb phone durcons)
egen totcons05=rsum(food sub1-sub11 edu elect fuel waterb computerbill phone durcons)

for var food sub1-sub11 edu elect fuel water phone computerbill durcons: recode X 0=.

* now we compute shares

gen fodsh=food/totcons
local i=1
while `i'<=11 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
gen comsh=computerbill/totcons

* Just to check
egen tot=rsum(fodsh-comsh)
sum tot
drop tot
* drop test
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace


*** Now we check education

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
egen medush=mean(edush)
egen sdedush=sd(edush)
gen test=1 if (edush>medush+2*sdedush) & edush!=.
count if test==1
sum edush if test==1, d
keep if test==1
keep hhid food totcons edu test edush acthhsize
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1", replace

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\eduexp", clear
egen edupc=rsum(preschool eduexp02 suptextbook excursion)
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp1"
tab _merge
gen newtype=1 if typep!=.
replace newtype=2 if type!=.
egen mean=mean(edupc), by(newtype)
gen share=edupc/totcons
egen max=max(share), by(hhid)
gen test1=edupc/mean
count if test1>10 & max==share & _merge==3

list hhid pfee pgift pservice edush if newtype==1 & test1>10 & max==share & _merge==3

gen correct=1 if newtype==1 & test1>10 & max==share & _merge==3 & pfee==12000
gen preschool1=preschool
replace preschool1=preschool1/10 if newtype==1 & test1>10 & max==share & _merge==3  & pfee==12000

list hhid totall transport fee-other tutor gift service if newtype==2 & test1>10 & max==share & _merge==3
list hhid totall transport fee-other tutor edush if newtype==2 & test1>10 & max==share & _merge==3
list hhid totall transport fee-other tutor type edush if newtype==2 & test1>10 & max==share & _merge==3

replace correct=1 if newtype==2 & test1>10 & max==share & _merge==3
gen school=eduexp02
gen school2=eduexp
gen school1=school
gen school3=school2
replace school1=school1/10 if newtype==2 & test1>10 & max==share & _merge==3
replace school3=school3/10 if newtype==2 & test1>10 & max==share & _merge==3
keep hhid school school1 school2 school3 preschool preschool1 correct 
egen edu=rsum(school3 preschool1)
collapse (sum) edu, by(hhid)
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\edu", replace


*** After these corrections we recalculate again total consumption

clear 
set mem 20m

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodexp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfoodexp1"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\edu"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilitiesjm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durcons1jm"
tab _merge
drop _merge

egen fuel=rsum(firewood-other)
egen phone=rsum(phonebill mobile)
egen totcons=rsum(food sub1-sub10 edu elect fuel waterb phone durcons)
egen totcons05=rsum(food sub1-sub11 edu elect fuel waterb computerbill phone durcons)

for var food sub1-sub11 edu elect fuel water phone computerbill durcons: recode X 0=.

* now we compute shares

gen fodsh=food/totcons
local i=1
while `i'<=11 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
gen comsh=computerbill/totcons

* Just to check
egen tot=rsum(fodsh-comsh)
sum tot
drop tot
* drop test
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace


*** Now we check utilities

* electricity

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
egen melesh=mean(elesh)
egen sdelesh=sd(elesh)
gen test=1 if elesh>melesh+2*sdelesh & elesh!=.
count if test==1
sum elesh if test==1, d
egen mean=mean(elect), by(areasq)
gen test1=elect/mean
sum elect mbill estbiladj if test==1 & test1>=5
gen diff=elect-estbiladj
gen share=diff/elect
sum share if test==1, d 
list hhid urbrur elect elesh estbiladj if share>0.25 & test==1
list hhid urbrur elect elesh estbiladj if share>0.5 & test==1
* we correct these values using the regression estimates
gen correct=1 if share>0.25 & test==1
replace elect=estbiladj if correct==1
keep hhid elect estbiladj mbill
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util2jm", replace

** fuel

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
egen mfuesh=mean(fuesh)
egen sdfuesh=sd(fuesh)
gen test=1 if fuesh>mfuesh+2*sdfuesh & fuesh!=.
count if test==1
sum fuesh if test==1, d
for var gascons firewood coal oilker diesel other: recode X 0=.
gen fuelpc1=gascons/acthhsize
gen fuelpc2=firewood/acthhsize
gen fuelpc3=coal/acthhsize
gen fuelpc4=oilker/acthhsize
gen fuelpc5=diesel/acthhsize
gen fuelpc6=other/acthhsize
local i=1
while `i'<=6 {
egen mean`i'=mean(fuelpc`i') if fuelpc`i'!=.
gen test`i'=fuelpc`i'/mean`i'
local i=`i'+1
}

for var test1 test2 test3 test4 test5 test6: recode X .=0
count if test==1 & (test1>=10 | test2>=10 | test3>=10 | test4>=10 | test5>=10 | test6>=10)
* corrections
gen correct=1 if test==1 & (test1>=10 | test2>=10 | test3>=10 | test4>=10 | test5>=10 | test6>=10)

list hhid firewood elect fuel fuesh test2 if correct==1

gen firesh=firewood/totcons
count if firesh>0.1 & firesh!=.
tab urbrur if firesh>0.1 & firesh!=.


keep hhid gascons firewood coal oilker diesel other correct
egen fuel=rsum( gascons firewood coal oilker diesel other)
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util3jm", replace

** phone

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
egen mphosh=mean(phosh)
egen sdphosh=sd(phosh)
gen test=1 if phosh>mphosh+2*sdphosh & phosh!=.
count if test==1
sum phosh if test==1, d
gen phonebpc=phonebill/acthhsize
gen mobpc=mobile/acthhsize
egen mean1=mean(phonebpc) if phonebpc>0
egen mean2=mean(mobpc) if mobpc>0
gen test1=phonebpc/mean1
gen test2=mobpc/mean2
count if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.))
list hhid urbrur phonebill mobile phosh test1 test2 if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.))
egen max=rmax(phonebill mobile) if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.))
* corrections
gen correct=1 if test==1 & ((test1>=5 & test1!=.) | (test2>=5 & test2!=.))
gen phonebill1=phonebill
replace phonebill1=phonebill/10 if correct==1 & phonebill==max
list hhid if correct==1 & phonebill==max
gen mobile1=mobile
replace mobile1=mobile/10 if correct==1 & mobile==max
list hhid if correct==1 & mobile==max

keep hhid phonebill mobile phonebill1 mobile1 correct
egen phone=rsum(phonebill1 mobile1)
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util4jm", replace

**** computerbill

use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
egen mcomsh=mean(phosh)
egen sdcomsh=sd(phosh)
gen test=1 if comsh>mcomsh+2*sdcomsh & comsh!=.
count if test==1
sum comsh if test==1, d
gen compc=computerbill/acthhsize
egen mean1=mean(compc) if compc>0
gen test1=compc/mean1
count if test==1 & ((test1>=5 & test1!=.))
list hhid urbrur computerbill comsh test1 if test==1 & ((test1>=5 & test1!=.))
egen max=max(computerbill) if test==1 & ((test1>=5 & test1!=.))
* corrections
gen correct=1 if test==1 & ((test1>=5 & test1!=.))
gen computerbill1=computerbill
replace computerbill1=computerbill/10 if correct==1 & computerbill==max
list hhid if correct==1 & computerbill==max

keep hhid computerbill1 computerbill correct
gen computer=computerbill1
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util5jm", replace


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilitiesjm", clear
keep hhid waterb areasq
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util6jm", replace


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util2jm", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util3jm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util4jm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util5jm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util6jm"
tab _merge
drop _merge
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilities1jm", replace


*********************************************************
***                 Total Consumption                 ***
*********************************************************


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\foodexp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\nfoodexp1"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\edu"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\utilities1jm"
tab _merge
drop _merge
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\durcons1jm"
tab _merge
drop _merge
sort hhid

egen totcons=rsum(food sub1-sub10 edu elect fuel waterb phone durcons)
egen totcons05=rsum(food sub1-sub11 edu elect fuel waterb computer phone durcons)


for var food food1 sub1-sub11 edu elect fuel water phone computerbill durcons: recode X 0=.

* now we compute shares

gen fodsh=food/totcons
local i=1
while `i'<=10 {
gen ssh`i'=sub`i'/totcons
local i=`i'+1
}
gen edush=edu/totcons
gen elesh=elect/totcons
gen fuesh=fuel/totcons
gen watsh=waterb/totcons
gen dursh=durcons/totcons
gen phosh=phone/totcons
gen comsh=computerbill/totcons

* Just to check
egen tot=rsum(fodsh-comsh)
sum tot
drop tot
* drop test
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", replace


use "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp", clear
sort hhid
merge hhid using "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\JMbase"
tab _merge
drop _merge
sort hhid

egen totcons1=rsum(food sub1-sub10 edu computerbill elect fuel waterb phone)
label var totcons "total consumption"
label var totcons1 "total consumption without durables"

keep hhid food food1 acthhsize durcons edu elect fuel waterb phone computer sub1-sub11 nfood
egen nfoodc=rsum(sub1-sub10)
egen nfood05=rsum(sub1-sub11)
egen totutil=rsum(elect fuel waterb phone)
egen totutil05=rsum(elect fuel waterb phone computer)

* Corrections to households incorrectly coded
replace hhid=509 if hhid==505
replace hhid=1502 if hhid==1505
replace hhid=2310 if hhid==2309
replace hhid=6902 if hhid==6901
replace hhid=8708 if hhid==8709
replace hhid=9308 if hhid==9309
replace hhid=16109 if hhid==16110
replace hhid=18210 if hhid==18211
replace hhid=23007 if hhid==23001
replace hhid=26009 if hhid==26010
replace hhid=26509 if hhid==26510
replace hhid=34210 if hhid==34206
replace hhid=34409 if hhid==34402
replace hhid=37507 if hhid==37506
replace hhid=41609 if hhid==41608
replace hhid=43211 if hhid==43201
replace hhid=44506 if hhid==44505
replace hhid=46411 if hhid==46410
drop if acthhsize==.
sort hhid
save "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 padata\totcons05", replace

drop _all

log close


!del "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\temp*.dta"
!del "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\group*.dta"
!del "C:\Documents and Settings\wb178469\My Documents\Albania\LSMS 2005 tempdata\util*.dta"
